@@ -16,13 +16,12 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with pytest-dbfixtures.  If not, see <http://www.gnu.org/licenses/>.
 """Fixture factory for postgresql client."""
-from typing import List, Optional, Callable, Union
+from typing import List, Optional, Callable, Union, Iterator
 
 import pytest
-from pytest import FixtureRequest
+from _pytest.fixtures import FixtureRequest
 
-from pytest_postgresql.compat import connection, check_for_psycopg2, psycopg2
-from pytest_postgresql.config import get_config
+from pytest_postgresql.compat import connection, check_for_psycopg, psycopg
 from pytest_postgresql.executor import PostgreSQLExecutor
 from pytest_postgresql.executor_noop import NoopExecutor
 from pytest_postgresql.janitor import DatabaseJanitor
@@ -32,8 +31,8 @@ def postgresql(
     process_fixture_name: str,
     dbname: Optional[str] = None,
     load: Optional[List[Union[Callable, str]]] = None,
-    isolation_level: Optional[int] = None,
-) -> Callable[[FixtureRequest], connection]:
+    isolation_level: "Optional[psycopg.IsolationLevel]" = None,
+) -> Callable[[FixtureRequest], Iterator[connection]]:
     """
     Return connection fixture factory for PostgreSQL.
 
@@ -47,15 +46,14 @@ def postgresql(
     """
 
     @pytest.fixture
-    def postgresql_factory(request: FixtureRequest) -> connection:
+    def postgresql_factory(request: FixtureRequest) -> Iterator[connection]:
         """
         Fixture factory for PostgreSQL.
 
         :param request: fixture request object
         :returns: postgresql client
         """
-        config = get_config(request)
-        check_for_psycopg2()
+        check_for_psycopg()
         proc_fixture: Union[PostgreSQLExecutor, NoopExecutor] = request.getfixturevalue(
             process_fixture_name
         )
@@ -65,13 +63,13 @@ def postgresql(
         pg_user = proc_fixture.user
         pg_password = proc_fixture.password
         pg_options = proc_fixture.options
-        pg_db = dbname or config["dbname"]
-        pg_load = load or config["load"]  # TODO: only a fixture param should be left here.
+        pg_db = dbname or proc_fixture.dbname
+        pg_load = load or []
 
         with DatabaseJanitor(
             pg_user, pg_host, pg_port, pg_db, proc_fixture.version, pg_password, isolation_level
         ) as janitor:
-            db_connection: connection = psycopg2.connect(
+            db_connection: connection = psycopg.connect(
                 dbname=pg_db,
                 user=pg_user,
                 password=pg_password,
